# X-Brain Bootstrap 4

[![Build Status](https://travis-ci.org/xbrain-dev/xbrain-bootstrap.svg?branch=master)](https://travis-ci.org/xbrain-dev/xbrain-bootstrap)
[![gzip size](http://img.badgesize.io/https://unpkg.com/xbrain-bootstrap/css/xbrain-bootstrap.min.css?compression=gzip)](https://unpkg.com/xbrain-bootstrap/css/xbrain-bootstrap.min.css)
[![npm](https://img.shields.io/npm/v/xbrain-bootstrap.svg)](http://npm.im/xbrain-bootstrap)
[![license](https://img.shields.io/github/license/xbrain-dev/xbrain-bootstrap.svg)](LICENSE)

> Bootstrap 4 flex grid system and layout utilities.

## What's Included

* [Reboot](https://getbootstrap.com/docs/4.0/getting-started/introduction/#reboot)
* [Grid](https://getbootstrap.com/docs/4.0/layout/grid/)
* [Layout Utilities](https://getbootstrap.com/docs/4.0/layout/utilities-for-layout/)
* [Text Utilities](https://getbootstrap.com/docs/4.0/utilities/text/)

## Motivation

Here's what you get that Bootstrap 4 currently doesn't provide out of the box:

* [Grid Equal-Width Multi-Row](https://getbootstrap.com/docs/4.0/layout/grid/#equal-width-multi-row)
* [Sizing Utility](https://getbootstrap.com/docs/4.0/utilities/sizing/)
* [Display Utility](https://getbootstrap.com/docs/4.0/utilities/display/)
* [Spacing Utility](https://getbootstrap.com/docs/4.0/utilities/spacing/)
* [Borders Utility](http://getbootstrap.com/docs/4.0/utilities/borders/)

If you don't need any of the above, Bootstrap 4 already includes a grid only
version with its
[Bootstrap CSS and JS](https://getbootstrap.com/docs/4.0/getting-started/download/#compiled-css-and-js)
bundle.

## Installation

### Npm

```bash
npm install xbrain-bootstrap
```

### Yarn

```bash
yarn add xbrain-bootstrap
```

## How to Use

Sass and CSS files are ready to be used in your project.

### CSS

Pretty straightforward. Just get `css/xbrain-bootstrap.min.css` or `css/xbrain-bootstrap.css` and add it
to your project.

### Sass

You will need to include the whole `scss` folder contents to your project. Then,
just import `xbrain-bootstrap.scss` into your project's sass file.

## Browser Support

We use [autoprefixer](https://github.com/postcss/autoprefixer) to add prefixes
to the `css` files. By default, the last 2 versions for each major browser is
supported. To change this, follow the customization instructions bellow.

**NOTE:** Sass files do not include any browser specific prefixes. If you
include them in your project, you will need to use your own post css tool to add
prefixes for different browsers.

## Grid Options

The grid options are located inside the `scss/xbrain-bootstrap.scss` file. If you are going
to be using the sass files in your project, changing those will suffice. If you
are going to be using the CSS files, then you will need to change the options
and then compile. For more details, see the customization instructions bellow.

**NOTE:** If you are using the sass files and you want to avoid your options
getting overridden by an update, then copy and paste the options to your own
sass file and include them before the `xbrain-bootstrap` file.

## Customization

You can roll your own build and/or change browser support.

### Requirements

* [NodeJS](https://nodejs.org/en/)
* [Grunt CLI](http://gruntjs.com/getting-started)
* [Sass](http://sass-lang.com/install) (not required for changing browser
  support)

Then install the dependencies:

#### With npm

```bash
npm install
```

#### With yarn

```bash
yarn install
```

### Change Browser Support

To change the default browser support (last 2 versions currently), you will need
to first change the query in the `browserlist` file, located at the root of this
project. Read more about the
[supported queries](https://github.com/ai/browserslist#queries).

Then, run:

```bash
grunt browser
```

### Change Grid Options

Open `scss/xbrain-bootstrap.scss` and change the
[default options](https://getbootstrap.com/docs/4.0/layout/grid/#customizing-the-grid).
Then, run:

```bash
grunt
```

> We changed the grid gutter width value to 16px because we are using material-ui.
